Enum Rotation

pub enum Rotation {
    Floating(Radians),
    Solid(Radians),
}
The strategy used to rotate the content.

This is used to control the behavior of the layout when the content is rotated by a certain angle.

Variants



Floating(Radians)

The element will float while rotating. The layout will be kept exactly as it was before the rotation.

This is especially useful when used for animations, as it will avoid the layout being shifted or resized when smoothly i.e. an icon.

This is the default.



Solid(Radians)

The element will be solid while rotating. The layout will be adjusted to fit the rotated content.

This allows you to rotate an image and have the layout adjust to fit the new size of the image.

Implementations



impl Rotation

pub fn radians(self) -> Radians

Returns the angle of the Rotation in Radians.

pub fn radians_mut(&mut self) -> &mut Radians

Returns a mutable reference to the angle of the Rotation in Radians.

pub fn degrees(self) -> Degrees

Returns the angle of the Rotation in Degrees.

pub fn apply(self, size: Size) -> Size

Applies the Rotation to the given Size, returning the minimum Size containing the rotated one.