Struct Application
pub struct Application<P>where
P: Program,{ /* private fields */ }Expand description
The underlying definition and configuration of an iced application.
You can use this API to create and run iced applications step by step—without coupling your logic to a trait or a specific type.
You can create an Application with the application helper.
Implementations
impl<P> Application<P>where
P: Program,
impl<P> Application<P>where
P: Program,
pub fn run(self) -> Result<(), Error>
pub fn run(self) -> Result<(), Error>
Runs the Application.
pub fn settings(self, settings: Settings) -> Application<P>
pub fn settings(self, settings: Settings) -> Application<P>
Sets the Settings that will be used to run the Application.
pub fn antialiasing(self, antialiasing: bool) -> Application<P>
pub fn antialiasing(self, antialiasing: bool) -> Application<P>
Sets the Settings::antialiasing of the Application.
pub fn default_font(self, default_font: Font) -> Application<P>
pub fn default_font(self, default_font: Font) -> Application<P>
Sets the default Font of the Application.
pub fn font(self, font: impl Into<Cow<'static, [u8]>>) -> Application<P>
pub fn font(self, font: impl Into<Cow<'static, [u8]>>) -> Application<P>
Adds a font to the list of fonts that will be loaded at the start of the Application.
pub fn window(self, window: Settings) -> Application<P>
pub fn window(self, window: Settings) -> Application<P>
Sets the window::Settings of the Application.
Overwrites any previous window::Settings.
pub fn centered(self) -> Application<P>
pub fn centered(self) -> Application<P>
Sets the window::Settings::position to window::Position::Centered in the Application.
pub fn exit_on_close_request(
self,
exit_on_close_request: bool,
) -> Application<P>
pub fn exit_on_close_request( self, exit_on_close_request: bool, ) -> Application<P>
Sets the window::Settings::exit_on_close_request of the Application.
pub fn window_size(self, size: impl Into<Size>) -> Application<P>
pub fn window_size(self, size: impl Into<Size>) -> Application<P>
Sets the window::Settings::size of the Application.
pub fn transparent(self, transparent: bool) -> Application<P>
pub fn transparent(self, transparent: bool) -> Application<P>
Sets the window::Settings::transparent of the Application.
pub fn resizable(self, resizable: bool) -> Application<P>
pub fn resizable(self, resizable: bool) -> Application<P>
Sets the window::Settings::resizable of the Application.
pub fn decorations(self, decorations: bool) -> Application<P>
pub fn decorations(self, decorations: bool) -> Application<P>
Sets the window::Settings::decorations of the Application.
pub fn position(self, position: Position) -> Application<P>
pub fn position(self, position: Position) -> Application<P>
Sets the window::Settings::position of the Application.
pub fn level(self, level: Level) -> Application<P>
pub fn level(self, level: Level) -> Application<P>
Sets the window::Settings::level of the Application.
pub fn title(
self,
title: impl TitleFn<<P as Program>::State>,
) -> Application<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>
pub fn title( self, title: impl TitleFn<<P as Program>::State>, ) -> Application<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>
Sets the title of the Application.
pub fn subscription(
self,
f: impl Fn(&<P as Program>::State) -> Subscription<<P as Program>::Message>,
) -> Application<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>
pub fn subscription( self, f: impl Fn(&<P as Program>::State) -> Subscription<<P as Program>::Message>, ) -> Application<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>
Sets the subscription logic of the Application.
pub fn theme(
self,
f: impl ThemeFn<<P as Program>::State, <P as Program>::Theme>,
) -> Application<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>
pub fn theme( self, f: impl ThemeFn<<P as Program>::State, <P as Program>::Theme>, ) -> Application<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>
Sets the theme logic of the Application.
pub fn style(
self,
f: impl Fn(&<P as Program>::State, &<P as Program>::Theme) -> Style,
) -> Application<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>
pub fn style( self, f: impl Fn(&<P as Program>::State, &<P as Program>::Theme) -> Style, ) -> Application<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>
Sets the style logic of the Application.
pub fn scale_factor(
self,
f: impl Fn(&<P as Program>::State) -> f32,
) -> Application<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>
pub fn scale_factor( self, f: impl Fn(&<P as Program>::State) -> f32, ) -> Application<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>
Sets the scale factor of the Application.
pub fn executor<E>(
self,
) -> Application<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>where
E: Executor,
pub fn executor<E>(
self,
) -> Application<impl Program<State = <P as Program>::State, Message = <P as Program>::Message, Theme = <P as Program>::Theme>>where
E: Executor,
Sets the executor of the Application.
pub fn presets(
self,
presets: impl IntoIterator<Item = Preset<<P as Program>::State, <P as Program>::Message>>,
) -> Application<P>
pub fn presets( self, presets: impl IntoIterator<Item = Preset<<P as Program>::State, <P as Program>::Message>>, ) -> Application<P>
Sets the boot presets of the Application.
Presets can be used to override the default booting strategy of your application during testing to create reproducible environments.